.. Packaging Scientific Python documentation master file, created by
   sphinx-quickstart on Thu Jun 28 12:35:56 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

gis-utils Documentation
=======================

.. toctree::
   :maxdepth: 2

   installation
   usage
   Code Reference <api/index>
   release-history
   min_versions
   troubleshooting
